@@ -1,7 +1,7 @@
 package App::picadata;
 use v5.14.1;
 
-our $VERSION = '2.00';
+our $VERSION = '2.01';
 
 use Getopt::Long qw(GetOptionsFromArray :config bundling);
 use Pod::Usage;
@@ -30,6 +30,7 @@ my %TYPES = (
     normpp => 'Plus',
     xml    => 'XML',
     ppxml  => 'PPXML',
+    pixml  => 'PIXML',
     json   => 'JSON',
     ndjson => 'JSON',
 );
@@ -67,7 +68,7 @@ sub new {
     };
 
     my %cmd = abbrev
-        qw(convert get count levels fields filter subfields sf explain validate build diff patch help version modify);
+        qw(convert get count levels fields filter subfields sf explain validate build diff patch help version modify join);
     if ($cmd{$argv[0]}) {
         $command = $cmd{shift @argv};
         $command =~ s/^sf$/subfields/;
@@ -91,8 +92,10 @@ sub new {
     if ($command eq 'modify') {
         die "missing path argument!\n" unless @argv;
         push @{$opt->{modify}}, parse_path(shift @argv);
-        die "missing value argument!\n" unless @argv;
-        push @{$opt->{modify}}, shift @argv;
+        my $value = shift @argv;
+        die "missing value argument!\n" unless defined $value;
+        utf8::decode($value);
+        push @{$opt->{modify}}, $value;
     }
 
     my $pattern = '[012.][0-9.][0-9.][A-Z@.](\$[^|]+|/[0-9.-]+)?';
@@ -174,7 +177,7 @@ sub new {
 
     # default output format
     unless ($opt->{to}) {
-        if ($command =~ /(convert|levels|filter|diff|patch|modify)/) {
+        if ($command =~ /(convert|levels|filter|diff|patch|modify|join)/) {
             $opt->{to} = $opt->{from};
             $opt->{to} ||= $TYPES{lc $1}
                 if $opt->{input}->[0] =~ /\.([a-z]+)$/;
@@ -285,6 +288,8 @@ sub run {
         ? PICA::Schema::Builder->new($schema ? %$schema : ())
         : undef;
 
+    my $joined = $command eq 'join' ? PICA::Data->new : undef;
+
     # additional options
     my $number  = $self->{number};
     my $stats   = {records => 0, holdings => 0, items => 0, fields => 0};
@@ -331,7 +336,7 @@ sub run {
             }
 
             if ($self->{annotate}) {
-                $record = pica_diff($before, $record);
+                $record = pica_diff($before, $record, keep => 1);
             }
         }
 
@@ -351,8 +356,13 @@ sub run {
             }
         }
 
-        $writer->write($record) if $writer;
-        $builder->add($record)  if $builder;
+        if ($joined) {
+            push @{$joined->{record}}, @{$record->{record}};
+        }
+        elsif ($writer) {
+            $writer->write($record);
+        }
+        $builder->add($record) if $builder;
 
         if ($command eq 'count') {
             $stats->{holdings}
@@ -410,7 +420,10 @@ sub run {
         }
     }
 
-    $writer->end() if $writer;
+    if ($writer) {
+        $writer->write($joined->sort) if $joined;
+        $writer->end();
+    }
 
     if ($command eq 'count') {
         $stats->{invalid} = $invalid;
